function [u,v] = source_type_plot(m);
% Usage: [u,v] = source_type_plot(m);

% Copyright 2018, David W. Eaton, University of Calgary, all rights reserved
%
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER "AS IS" AND ANY EXPRESS OR 
% IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
% MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT 
% SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
% INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED 
% TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR 
% BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
% STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
% OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

%
% Generates a source type plot as defined by Hudson et al. JGR (1989)
%
% m = [n x 6] array of moment-tensors values
%

close all;

[nm,n6] = size(m);

for im = 1:nm;

    
    mm = m(im,:);
    
    M(1,1) = m(im,1);
    M(2,2) = m(im,2);
    M(3,3) = m(im,3);
    M(1,2) = m(im,4);
    M(2,1) = M(1,2);
    M(1,3) = m(im,5);
    M(3,1) = M(1,3);
    M(2,3) = m(im,6);
    M(3,2) = M(2,3);
    
    [V,D] = eig(M);
    
    ev = [D(1,1),D(2,2),D(3,3)];
    evs = sort(ev,'descend');
    
    Mx = evs(1);
    Mz = evs(2);
    My = evs(3);
    
    % Eq. 2
    M = sum(evs)/3;
    
    % Eq. 3
    Mxp = Mx - M;
    Myp = My - M;
    Mzp = Mz - M;
    
    % Eq. 18
    if Mzp >= 0;
        k = M/(abs(M)-Myp);
    else    
        k = M/(abs(M)+Mxp);
    end
    
    % Eq. 19
    if Mzp > 0;
        T = -2*Mzp/Myp;
    elseif Mzp < 0;
        T = 2*Mzp/Mxp;
    else
        T = 0;
    end
    
    % Eq. 28
    mu = M/(2*k);
    tau = T*(1 - abs(k));
    
    % Eq. 49
    if tau >= 0 & k <= 0;
        u(im) = tau;
        v(im) = k;
    end
    
    if tau <= 0 & k >= 0;
        u(im) = tau;
        v(im) = k;
    end
    
    % Eq. 51
    if tau >= 0 & k >= 0;
        
        % Region B
        if tau >= 4*k;
            u(im) = tau/(1-2*k);
            v(im) = k/(1-2*k);
        else
            % Region A
            u(im) = tau/(1-tau/2);
            v(im) = k/(1-tau/2);
            
        end
    end

    
    % Eq. 54
    if tau <=0 & k <=0;

        if tau >= 4*k;
            u(im) = tau/(1+tau/2);
            v(im) = k/(1+tau/2);
        else
            u(im) = tau/(1+2*k);
            v(im) = k/(1+2*k);
        end
    end
    
end

xv = [0,-4/3,0,4/3,0];
yv = [1,-1/3,-1,1/3,1];

plot(xv,yv,'k');
axis equal;
hold on;

plot(u,v,'ro','MarkerFaceColor','r');
plot([-1,1],[0,0]);
plot([0,0],[-1,1]);

axis tight;
%title('Source Type Plot');

axis off;
text(1,-0.05,'-CLVD');
text(-1.2,0.05,'+CLVD');
text(-0.84,0.33,'+LD');
text(0.73,-0.36,'-LD');
text(-0.62,0.56,'TCO');
text(0.5,-0.56,'TCC');
text(-0.1,-0.05,'DC');

text(-0.15,1.1,'Explosion');
text(-0.15,-1.1,'Implosion');

fh = figure(1); % returns the handle to the figure object
set(fh, 'color', 'white'); % sets the color to white




    
    
        
        
    
    
    
    
    
   
    % D. Eaton
%
% BEGIN TERMS OF USE LICENSE
%
% This SOFTWARE is maintained by the Microseismic Industry Consortium 
% in the Department of Geoscience of the University of Calgary, Calgary,
% Alberta, Canada.  The copyright and ownership are jointly held by 
% its author (identified above) and the Microseismic Industry Consortium.  
% The Microseismic Industry Consortium project may be contacted via email at:  
% eatond@ucalgary.ca
% 
% The term 'SOFTWARE' refers to the Matlab source code, translations to
% any other computer language, or object code
%
% Terms of use of this SOFTWARE
%
% 1) Use of this SOFTWARE by any for-profit commercial organization is
%    expressly forbidden unless said organization is a Microseismic Industry 
% Consortium Project Sponsor.
%
% 2) A Microseismic Industry Consortium Project sponsor may use this SOFTWARE 
% under the terms of theMicroseismic Industry Consortium Project Sponsorship 
% agreement.
%
% 3) A student or employee of a non-profit educational institution may 
%    use this SOFTWARE subject to the following terms and conditions:
%    - this SOFTWARE is for teaching or research purposes only.
%    - this SOFTWARE may be distributed to other students or researchers 
%      provided that these license terms are included.
%    - reselling the SOFTWARE, or including it or any portion of it, in any
%      software that will be resold is expressly forbidden.
%    - transfering the SOFTWARE in any form to a commercial firm or any 
%      other for-profit organization is expressly forbidden.
%
%
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
% IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
% THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
% PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
% CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
% EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
% PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
% PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
% LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
% NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
% SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
%
% END TERMS OF USE LICENSE
