function [raa,ang] = zprtz(vp1,vp2,vs1,vs2,rho1,rho2,incw,alpha);
%Usage: [raa,ang] = zprtz(vp1,vp2,vs1,vs2,rho1,rho2,incw,alpha);

% THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR 
% IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
% MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT 
% SHALL THE CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
% INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED 
% TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR 
% BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
% STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
% OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

%
%        PROGRAM FROM YOUNG G.B. AND L.W.BRAILE 1976,
%       BULLETIN OF THE SEISMOLOGICAL SOCIETY OF AMERICA,
%       VOL.66 NO.6 P.1881-1885.
%    *****INPUT*******
%       VP1,VP2,VS1,VS2,RHO1,RHO2. P WAVE AND S WAVE VELOCITIES
%               AND DENSITIES WHERE (1) INDICATE THE LAYER WHERE
%               INCIDENCE OCCURS.
%       INCW = 1 IF INCIDENT WAVE IS COMPRESSIONAL
%              2 IF INCIDENT WAVE IS SHEAR
%       ALPHA= ANGLE OF INCIDENCE IN RADIANS
%    *****OUTPUT*******
%       RAA(J) DISPLACEMENT AMPLITUE
%               J= 1 FOR REFLECTED P WAVE
%                  2 FOR REFLECTED SV WAVE
%                  3 FOR TRANSMITTED P WAVE
%                  4 FOR TRANSMITTED SV WAVE
%       ANG(J) = PHASE ANGLE IN RADIANS

      if incw == 1
	 vel=vp1;
      end

      if incw == 2
	 vel=vs1;
      end

      theta = sin(alpha)/vel;
      fac1=1.0;
      fac2=1.0;
      fac3=1.0;
      fac4=1.0;
      thetasq=theta^2;
      qa=2.0*(rho2*vs2^2-rho1*vs1^2);
      t1=vp1^2*thetasq;
      t2=vs1^2*thetasq;
      t3=vp2^2*thetasq;
      t4=vs2^2*thetasq;

%        TEST FOR CRITICAL P REFLECTION
      	if theta > 1.0/vp1;
		b1 = -sqrt(t1-1.0);
		a1 = 0.0;
      		fac1 = 0.0;
      	else
		a1 = sqrt(1.0-t1);
		b1 = 0.0;
      	end

%         TEST FOR CRITICAL S REFLECTION
	if theta > 1.0/vs1;
		b2 = -sqrt(t2-1.0);
      	   	a2 = 0.0;
      	   	fac2 = 0.0;
	else
      		a2 = sqrt(1.0-t2);
      		b2 = 0.0;
	end

%         TEST FOR CRITICAL P REFRACTION
	if theta > 1.0/vp2;
		b3 = -sqrt(t3-1.0);
      		a3 = 0.0;
		fac3 = 0.0;
	else
      		a3 = sqrt(1.0-t3);
      		b3 = 0.0;
	end

%         TEST FOR CRITICAL S REFRACTION
	if theta > 1.0/vs2;
	   	b4 = -sqrt(t4-1.0);
	   	a4 = 0.0;
	   	fac4 = 0.0;
	else
      		a4 = sqrt(1.0-t4);
      		b4 = 0.0;
	end

   	x = rho2 - qa*thetasq;
      	y = rho1 + qa*thetasq;
      	z = rho2 - rho1 -qa*thetasq;
      	z1 = rho1 - rho2 + qa*thetasq;
      	p1 = a1 + b1*i;
      	p2 = a2 + b2*i;
      	p3 = a3 + b3*i;
      	p4 = a4 + b4*i;

      	d = vp1*vp2*vs1*vs2*thetasq*z^2 + vp2*vs2*p1*p2*x^2 + vp1*vs1*p3*p4*y^2 + rho1*rho2*(vs1*vp2*p1*p4 + vp1*vs2*p2*p3) + qa^2*thetasq*p1*p2*p3*p4;

%***************************************************************
%        COMPLETE THE COEFFICIENTS
%***************************************************************

	if incw == 1;  

		r(1,1) = -1.0+2.0*p1*(vp2*vs2*p2*x^2 + vs1*vp2*rho1*rho2*p4 + qa^2*thetasq*p2*p3*p4)/d;
      		r(1,2) = -2.0*vp1*theta*p1*(qa*p3*p4*y+vp2*vs2*x*z)*fac2/d;
      		r(1,3) = 2.0*vp1*rho1*p1*(vs2*p2*x+vs1*p4*y)*fac3/d;
      		r(1,4) = -2.0*vp1*rho1*theta*p1*(qa*p2*p3-vs1*vp2*z)*fac4/d;
%        FACTOR TO DETERMINE RPA(**)
      		fp(1,1) = 1.0;
      		fp(1,2) = vs1/vp1;
      		fp(1,3) = vp2/vp1;
      		fp(1,4) = vs2/vp1;
%        FACTOR TO DETERMINE REA(**)
      		fe(1,1) = 1.0;
      		fe(1,2) = p2*vp1/(p1*vs1);
      		fe(1,3) = rho2*p3*vp1/(p1*vp2*rho1);
      		fe(1,4) = rho2*p4*vp1/(rho1*p1*vs2);

	else

		r(2,1) = -2.0*vs1*theta*p2*(qa*p3*p4*y+vp2*vs2*x*z)*fac1/d;
      		r(2,2) = 1.0 - 2.0*p2*(vp2*vs2*p1*x^2+vp1*vs2*rho1*rho2*p3 + qa^2*thetasq*p1*p3*p4)/d;
      		r(2,3) = 2.0*vs1*rho1*theta*p2*(qa*p1*p4-vp1*vs2*z)*fac3/d;
      		r(2,4) = 2.0*vs1*rho1*p2*(vp1*p3*y + vp2*p1*x)*fac4/d;
%        FACTOR TO DETERMINE RPA(**)
      		fp(2,1) = vp1/vs1;
      		fp(2,2) = 1.0;
      		fp(2,3) = vp2/vs1;
      		fp(2,4) = vs2/vs1;
%        FACTOR TO DETERMINE REA(**)
      		fe(2,1) = vs1*p1/(vp1*p2);
      		fe(2,2) = 1.0;
      		fe(2,3) = rho2*vs1*p3/(rho1*vp2*p2);
      		fe(2,4) = rho2*vs1*p4/(rho1*vs2*p2);

	end

	ii = incw;

      	for j = 1:4;

			raa(j) = abs(r(ii,j));
      		rra = real(r(ii,j));
      		ria = imag(r(ii,j));

      		if abs(rra) > 0.0000001;
			ang(j) = atan2(ria,rra);
		else
      			ang(j) = 0.0;
		end
 	end

